loadPSO = require 'PSO'
rocket = {x = 400, y = 600, v = 0, oldV = 0, a = 0, r = 6, m = 10000}
rocket.ps1 = loadPSO "Rocket2.pso"[1].ps
rocket.ps2 = loadPSO "Rocket2.pso"[2].ps
rocket.ps3 = loadPSO "Rocket2.pso"[3].ps
rocket.ps3:setPosition(rocket.x, rocket.y)
rocket.ps3:stop()

m = {' meters (here ends the first stage', ' meters (no fuel!)', ' meters (top height)'}

height = {[0] = 150, [-1] = 37.5, [-2] = 75, [-3] = 112.5, [-4] = 0, [-5] = 450, [-6] = 300, [-7] = 150, [-8] = 600}
speed = {[0] = 295.09272804982, [-1] = 249.29959091464, [-2] = 340.885865185, [-3] = 386.67900232019, [-4] = -1, [-5] = 50, [-6] = -50, [-7] = -100, [-8] = 0}
accel = {[0] = 530, [-1] = 460, [-2] = 495, [-3] = 565, [-4] = 600, [-5] = 10, [-6] = 5, [-7] = -5, [-8] = -10}

meter = 1

timer = 0

oldT = 0

love.update = function(dt)

	dt = pause and 0 or dt

	timer = timer + dt
	
	rocket.ps1:update(dt)
	rocket.ps2:update(dt)
	rocket.ps3:update(dt)

	rocket.a = 10

	if timer >= 3 then
	
		if oldT < 3 then
		
			rocket[1] = 600-rocket.y
			rocket.ps1:stop()
			
		end

		rocket.a = 4.29

		if timer >= 10 then
		
			if oldT < 10 then
			
				rocket[2] = 600-rocket.y
				rocket.ps2:stop()
				
			end
			
			if rocket.v <= 0 and not rocket[3] then
			
				rocket[3] = 600-rocket.y
				
			end

			rocket.a = -10

			if rocket.y > 600 and rocket.x == 400 then

				rocket.x = -50
				rocket.ps3:start()

			end

		end

	end

	rocket.v = rocket.v + rocket.a*dt

	rocket.y = rocket.y - rocket.v*meter*dt
	
	rocket.ps1:setPosition(400-9.5, rocket.y-5)
	rocket.ps2:setPosition(400-9.5, rocket.y-5)
	
	table.insert(height, timer*7.5890547252207+600)
	table.insert(height, rocket.y/4)
	
	table.insert(speed, timer*7.5890547252207+600)
	table.insert(speed, 350-(rocket.v+59.95142)*0.91586274270363)
	
	table.insert(accel, timer*7.5890547252207+600)
	table.insert(accel, 600-(rocket.a+10)*7)
	
	oldT = timer

end

love.draw = function()

	love.graphics.setColor(255,255,255)

	love.graphics.circle('fill', rocket.x, rocket.y, rocket.r, rocket.r*4)
	
	love.graphics.draw(rocket.ps1, 0, 0)
	love.graphics.draw(rocket.ps2, 0, 0)
	love.graphics.draw(rocket.ps3, 0, 0)
	
	
	---[[
	for i = 1, 600/15 do

		love.graphics.print(i*15, 0, 600-i*15)
	
	end--]]
	
	
	--[[
	local y = 600-rocket.y
	
	love.graphics.print('150', 0, y*10-300)
	love.graphics.print('300', 0, y*10-600-300)
	love.graphics.print('450', 0, y*10-1200-300)
	love.graphics.print('600', 0, y*10-1800-300)--]]
	
	if #height < 4 then return end
	
	love.graphics.line(height)
	love.graphics.print(0, 592, height[0]-6)
	love.graphics.printf('height (m)', 600, height[0], 200, 'right')
	love.graphics.line(600, height[0], 800, height[0])
	
	love.graphics.line(speed)
	love.graphics.print(0, 592, speed[0]-6)
	love.graphics.printf('speed (m/s)', 600, speed[0], 200, 'right')
	love.graphics.line(600, speed[0], 800, speed[0])
	
	love.graphics.line(accel)
	love.graphics.print(0, 592, accel[0]-6)
	love.graphics.printf('acceleration (m/s^2)', 600, accel[0], 200, 'right')
	love.graphics.line(600, accel[0], 800, accel[0])
	
	
	for i, v in ipairs(rocket) do
	
		love.graphics.line(0, 600-v, 400, 600-v)
		love.graphics.print(v..m[i], 32, 600-v-14)
		
	end
	
	
	love.graphics.setColor(255,255,255,160)
	
	for i = -4, -1 do
	
		love.graphics.line(600, height[i], 800, height[i])
		love.graphics.print(math.floor(height[i-4]), 575, height[i]-6)
		
		love.graphics.line(600, speed[i], 800, speed[i])
		love.graphics.print(math.floor(speed[i-4]), 575, speed[i]-6)
		
		love.graphics.line(600, accel[i], 800, accel[i])
		love.graphics.print(math.floor(accel[i-4]), 575, accel[i]-6)
		
	end

end

love.keypressed = function(k, u)

	if k == ' ' then pause = not pause end
	
	if k == 'f' then love.graphics.toggleFullscreen() end
	
end

love.quit = function()

	h = love.filesystem.newFile 'h.log'
	h:open('w')
	s = love.filesystem.newFile 's.log'
	s:open('w')
	a = love.filesystem.newFile 'a.log'
	a:open('w')
	local _
	
	for i = 1, #height do
	
		vh = height[i]
		vs = speed[i]
		va = accel[i]
		
		h:write(vh)
		s:write(vs)
		a:write(va)
		
		_ = (i%2==0) and (h:write('\n')) or (h:write(', '))
		_ = (i%2==0) and (s:write('\n')) or (s:write(', '))
		_ = (i%2==0) and (a:write('\n')) or (a:write(', '))
		
	end
	
	h:close()
	s:close()
	a:close()
	
end